;; Generated package description from tramp-theme.el  -*- no-byte-compile: t -*-
(define-package "tramp-theme" "0.2" "Custom theme for remote buffers" '((emacs "24.1")) :commit "e23d7a390278feea8b5652da49052a16dfbbfc3f" :url "https://elpa.gnu.org/packages/tramp-theme.html" :authors '(("Michael Albinus" . "michael.albinus@gmx.de")) :maintainer '("Michael Albinus" . "michael.albinus@gmx.de") :keywords '("convenience" "faces"))
